#
# spec file for package libreplaygain
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 1

Name:           libreplaygain
Summary:        Library for analyzing sound and recommending volume change
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Version:        r475
Release:        3.5
URL:            https://www.musepack.net/
Source0:        https://files.musepack.net/source/%{name}_%{version}.tar.gz
Patch0:         libreplaygain-math.patch
BuildRequires:  cmake

%description
libreplaygain is a library that analyzes input samples and gives the
recommended volume change.

%package devel
Summary:        Development files for libreplaygain
Group:          Development/Libraries/C and C++
Requires:       libreplaygain%{so_ver} = %{version}

%description devel
This package includes development files for libreplaygain.

%package -n libreplaygain%{so_ver}
Summary:        Library for analyzing sound and recommending volume change
Group:          System/Libraries

%description -n libreplaygain%{so_ver}
libreplaygain is a library that analyzes input samples and gives the
recommended volume change.

%prep
%autosetup -p1 -n %{name}_%{version}

%build
# Fix rpmlint error "spurious-executable-perm"
chmod 644 include/replaygain/*.h

# Make the package use rpm optflags
sed -i "s/set(CMAKE_C_FLAGS.*$//" CMakeLists.txt

%cmake
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_includedir}
cp -a include/replaygain/ %{buildroot}%{_includedir}

rm -f %{buildroot}%{_libdir}/*.a

%post -n libreplaygain%{so_ver} -p /sbin/ldconfig

%postun -n libreplaygain%{so_ver} -p /sbin/ldconfig

%files devel
%{_includedir}/replaygain/
%{_libdir}/libreplaygain.so

%files -n libreplaygain%{so_ver}
%{_libdir}/libreplaygain.so.%{so_ver}*

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Make descriptions more meaningful.
* Thu Jul  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- More spec file cleanup:
  * Use SPDX identifier to License
  * Use https:// for Source and Url
  * Remove BuildRoot
* Fri Jun 21 2019 mgorse@suse.com
- Add libreplaygain-math.patch: link with -lm.
- Use cmake macros.
- Move source modifications from %%prep to %%build. Makes 'quilt
  setup' more robust.
- Remove some unneeded comments from %%install.
- Remove %%defattr.. No longer needed.
* Sun Mar 10 2013 asterios.dramis@gmail.com
- Correct version number to r475.
* Sun Mar 10 2013 asterios.dramis@gmail.com
- Initial rpm release (version 20110810_r475).
